function val = get(hellip, propName)
    % GET Get hyperellipsoid property from the specified object
    % and return the value. Property names are: 
    %    center, shape, and size
%GET(hellip, propName) Retrieve a property of a hyperellipsoid object
%
% Syntax:      val = get(hellip, propName)
%
% Inputs:
%              hellip - a valid hyperellipsoid object
%              propName - a name of the desired property
%
% Outputs:     val - the value of the indicated property
%
% Example: 
%              % Read the center of an ellipsoid:
%              mu = get(hellip, 'center');
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EITHER EXPRESS, IMPLIED, STATUTORY OR OTHERWISE INCLUDING BUT NOT LIMITED TO
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, FREE OF
% DEFECTS AND NONINFRINGEMENT. 
% 
% UNDER NO CIRCUMSTANCES AND UNDER NO LEGAL THEORY OF LIABILITY, WHETHER TORT
% (INCLUDING NEGLIGENCE), CONTRACT OR OTHERWISE SHALL THE AUTHORS OR THEIR 
% EMPLOYERS BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR 
% CONSEQUENTIAL DAMAGES OF ANY KIND, INCLUDING, WITHOUT LIMITATION, DAMAGES 
% FOR LOST PROFITS, LOSS OF GOODWILL, WORK STOPPPAGE, COMPUTER FAILURE OR 
% MALFUNCTION, LOSS OF USE, LOSS OF DATA, OR ANY AND ALL OTHER COMMERCIAL 
% DAMAGES AND LOSSES WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES, 
% ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE. 
% THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH 
% YOU. IF THE SOFTWARE PROVES DEFECTIVE IN ANY RESPECT, YOU ASSUME THE COST OF 
% ANY NECESSARY SERVICING, REPAIR OR CORRECTION  
% THIS SOFTWARE IS RELEASED INTO THE PUBLIC DOMAIN, OCT 2012.

% Author: Mark D. Flood
% Research and Analysis Center, Office of Financial Research
% Oct 2012; Last revision: 21-Nov-2010

%------------- BEGIN CODE --------------
    switch propName
    case 'center'
       val = hellip.center;
    case 'shape'
       val = hellip.shape;
    case 'size'
       val = hellip.size;
    otherwise
       error([propName ,'Is not a valid hyperellipsoid property'])
    end
end