function [hell, mu] = center_at_origin(hellipse)
%CENTER_AT_ORIGIN Creates a new ellipsoid object equivalent to the given
%                hyperellipsoid (hellipse), but centered at the origin.
%
% Syntax:      [hell, mu] = center_at_origin(hellipse)
%
% Inputs:
%              hellipse - the original object, to be shifted
%
% Outputs:
%              hell - the re-centered hyperellipsoid
%              mu - the amount of the translation
%
% Example: 
%              mu = [9; 6];
%              sig = 3*eye(2);
%              e = hyperellipsoid(mu, sig, 5);
%              [e2, mu1] = center_at_origin(e);
%              result = get(e2, 'center');
%              assertEquals('Center is 0,0', result(1, 1), 0);
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EITHER EXPRESS, IMPLIED, STATUTORY OR OTHERWISE INCLUDING BUT NOT LIMITED TO
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, FREE OF
% DEFECTS AND NONINFRINGEMENT. 
% 
% UNDER NO CIRCUMSTANCES AND UNDER NO LEGAL THEORY OF LIABILITY, WHETHER TORT
% (INCLUDING NEGLIGENCE), CONTRACT OR OTHERWISE SHALL THE AUTHORS OR THEIR 
% EMPLOYERS BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR 
% CONSEQUENTIAL DAMAGES OF ANY KIND, INCLUDING, WITHOUT LIMITATION, DAMAGES 
% FOR LOST PROFITS, LOSS OF GOODWILL, WORK STOPPPAGE, COMPUTER FAILURE OR 
% MALFUNCTION, LOSS OF USE, LOSS OF DATA, OR ANY AND ALL OTHER COMMERCIAL 
% DAMAGES AND LOSSES WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES, 
% ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE. 
% THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH 
% YOU. IF THE SOFTWARE PROVES DEFECTIVE IN ANY RESPECT, YOU ASSUME THE COST OF 
% ANY NECESSARY SERVICING, REPAIR OR CORRECTION  
% THIS SOFTWARE IS RELEASED INTO THE PUBLIC DOMAIN, OCT 2012.

% Author: Mark D. Flood
% Research and Analysis Center, Office of Financial Research
% Oct 2012; Last revision: 21-Nov-2010

%------------- BEGIN CODE --------------
    mu = get(hellipse, 'center');
    sig = get(hellipse, 'shape');
    c = get(hellipse, 'size');
    hell = hyperellipsoid(zeros(length(mu), 1), sig, c);
end
